@@ -88,7 +88,7 @@ public:
 // user defined declarations:
 public:
 
-# 156 "/build/kdevelop-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 143 "/build/kdevelop-php/src/kdev-php-21.12.0/parser/php.g" 1
 
     /**
      * Transform the raw input into tokens.
@@ -124,7 +124,7 @@ public:
 
 private:
 
-# 188 "/build/kdevelop-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 175 "/build/kdevelop-php/src/kdev-php-21.12.0/parser/php.g" 1
 
     enum VarExpressionState
     {
@@ -169,7 +169,7 @@ public:
 
 // user defined constructor code:
 
-# 209 "/build/kdevelop-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 196 "/build/kdevelop-php/src/kdev-php-21.12.0/parser/php.g" 1
 
         m_state.varExpressionState = Normal;
         m_state.varExpressionIsVariable = false;
@@ -270,6 +270,8 @@ public:
     bool parseParameterType(ParameterTypeAst **yynode);
     bool parsePostprefixOperator(PostprefixOperatorAst **yynode);
     bool parsePrintExpression(PrintExpressionAst **yynode);
+    bool parsePropertyType(PropertyTypeAst **yynode);
+    bool parsePropertyTypeHint(PropertyTypeHintAst **yynode);
     bool parseRelationalExpression(RelationalExpressionAst **yynode);
     bool parseRelationalExpressionRest(RelationalExpressionRestAst **yynode);
     bool parseReservedNonModifierIdentifier(ReservedNonModifierIdentifierAst **yynode);
@@ -299,6 +301,7 @@ public:
     bool parseUnaryExpression(UnaryExpressionAst **yynode);
     bool parseUnaryExpressionNotPlusminus(UnaryExpressionNotPlusminusAst **yynode);
     bool parseUseNamespace(UseNamespaceAst **yynode);
+    bool parseUseStatement(UseStatementAst **yynode);
     bool parseVarExpression(VarExpressionAst **yynode);
     bool parseVarExpressionArray(VarExpressionArrayAst **yynode);
     bool parseVarExpressionNewObject(VarExpressionNewObjectAst **yynode);
